@@ -117,6 +117,44 @@ plot.BMMposteriori <- function(x, caption, main = "", ...) {
 # Plot method for jags objects adapted from plot.mcmc in package coda
 # written by Martyn Plummer, Nicky Best, Kate Cowles, Karen Vines
 
+set.mfrow <- function (Nchains = 1, Nparms = 1, nplots = 1, sepplot = FALSE) 
+{
+    mfrow <- if (sepplot && Nchains > 1 && nplots == 1) {
+        if (Nchains == 2) {
+            switch(min(Nparms, 5), c(1, 2), c(2, 2), c(3, 2), 
+                c(4, 2), c(3, 2))
+        }
+        else if (Nchains == 3) {
+            switch(min(Nparms, 5), c(2, 2), c(2, 3), c(3, 3), 
+                c(2, 3), c(3, 3))
+        }
+        else if (Nchains == 4) {
+            if (Nparms == 1) 
+                c(2, 2)
+            else c(4, 2)
+        }
+        else if (any(Nchains == c(5, 6, 10, 11, 12))) 
+            c(3, 2)
+        else if (any(Nchains == c(7, 8, 9)) || Nchains >= 13) 
+            c(3, 3)
+    }
+    else {
+        if (nplots == 1) {
+            mfrow <- switch(min(Nparms, 13), c(1, 1), c(1, 2), 
+                c(2, 2), c(2, 2), c(3, 2), c(3, 2), c(3, 3), 
+                c(3, 3), c(3, 3), c(3, 2), c(3, 2), c(3, 2), 
+                c(3, 3))
+        }
+        else {
+            mfrow <- switch(min(Nparms, 13), c(1, 2), c(2, 2), 
+                c(3, 2), c(4, 2), c(3, 2), c(3, 2), c(4, 2), 
+                c(4, 2), c(4, 2), c(3, 2), c(3, 2), c(3, 2), 
+                c(4, 2))
+        }
+    }
+    return(mfrow)
+}
+
 plot.jags <- function (x, variables = NULL, trace = TRUE, density = TRUE, 
                        smooth = TRUE, bwf, num, xlim, auto.layout = TRUE, ask = interactive(), ...)  
 {
@@ -136,8 +174,8 @@ plot.jags <- function (x, variables = NULL, trace = TRUE, density = TRUE,
         oldpar <- NULL
         on.exit(par(oldpar))
         if (auto.layout) {
-          mfrow <- coda:::set.mfrow(Nchains = nchain(u), Nparms = nvar(u), 
-                                    nplots = trace + density)
+          mfrow <- set.mfrow(Nchains = nchain(u), Nparms = nvar(u), 
+                             nplots = trace + density)
           oldpar <- par(mfrow = mfrow)
         }
         oldpar <- c(oldpar, par(ask = ask))
